// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Carousel from 'components/Carousel'

const ImageCarousel = ({
  theme,
  items,
  renderItem,
  imageField = 'image',
  darken = 0,
  ...props
}: {
  theme: { [key: string]: string },
  imageField?: string,
  darken: number,
  renderItem: Function,
  items: Array<any>,
}) => (
  <Carousel
    theme={theme}
    items={items}
    {...props}
    renderItem={item => (
      <div
        key={item[imageField]}
        className={cn('relative cover', theme.slideWrapper)}
        style={{
          backgroundImage: `linear-gradient(rgba(0, 0, 0, ${darken}), rgba(0, 0, 0, ${darken})), url(${item[imageField]})`,
        }}
      >
        <div
          className={cn('absolute absolute--fill', theme.slideContent)}
        >
          {renderItem(item)}
        </div>
      </div>
    )}
  />
)

ImageCarousel.defaultProps = {
  imageField: 'image',
}

export default themr('ImageCarousel', {}, { composeTheme: 'softly' })(ImageCarousel)
